@@ -23,14 +23,30 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
 # USA
 
-import os.path
+import os
+import sys
 import gettext
 
 from SystrayNanny import SystrayNanny
 
-icons_files_dir= os.path.join("/usr/local","share/icons/hicolor")
+if os.name == "posix":
+    icons_files_dir= os.path.join("/usr","share/icons/hicolor")
+    locale_dir = os.path.join("/usr", "share/" ,"locale/")
+elif os.name == "nt":
+    if not hasattr(sys, "frozen") :
+        file_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+        for x in range(8):
+            file_dir = os.path.dirname(file_dir)
+
+        root_path = file_dir
+        icons_files_dir = os.path.join(root_path, "share" , "icons", "hicolor" )
+        locale_dir = os.path.join(root_path, "share" ,"locale")
+    else:
+        root_path = os.path.dirname(os.path.dirname(unicode(sys.executable, sys.getfilesystemencoding( ))))
+        icons_files_dir = os.path.join(root_path, "share" , "icons", "hicolor" )
+        locale_dir = os.path.join(root_path, "share" ,"locale")
 
 GETTEXT_DOMAIN = 'nanny'
-locale_dir = os.path.join("/usr/local", "share/" ,"locale/")
+
 gettext.bindtextdomain(GETTEXT_DOMAIN, locale_dir)
 gettext.textdomain(GETTEXT_DOMAIN)
