@@ -23,7 +23,13 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
 # USA
 
-from LinuxUsersManager import LinuxUsersManager as UsersManager
+import os
+ 
+if os.name == "posix" :
+    from LinuxUsersManager import LinuxUsersManager as UsersManager
+elif os.name == "nt" :
+    from Win32UsersManager import Win32UsersManager as UsersManager
+
 from QuarterBack import QuarterBack
 from Daemon import Daemon
 
